Skip to contents

Print the information about the distribution of the known component of an admixture model, as well as the known parameters for this distribution.

Usage

# S3 method for class 'admix_model'
print(x, ...)

Arguments

x

An object of class admix_model.

...

A list of additional parameters belonging to the default method.

Author

Xavier Milhaud xavier.milhaud.research@gmail.com